@@ -72,7 +72,14 @@ describe 'ceilometer::agent::polling' do
 
       it { should contain_ceilometer_config('polling/batch_size').with_value('<SERVICE DEFAULT>') }
       it { should_not contain_file('polling') }
-      it { should contain_ceilometer_config('polling/tenant_name_discovery').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/identity_name_discovery').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/ignore_disabled_projects').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/enable_notifications').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/enable_prometheus_exporter').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/prometheus_listen_addresses').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/prometheus_tls_enable').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/prometheus_tls_certfile').with_value('<SERVICE DEFAULT>') }
+      it { should contain_ceilometer_config('polling/prometheus_tls_keyfile').with_value('<SERVICE DEFAULT>') }
       it { should contain_ceilometer_config('polling/pollsters_definitions_dirs').with_value('<SERVICE DEFAULT>') }
       it { should contain_ceilometer_config('polling/cfg_file').with_value('<SERVICE DEFAULT>') }
     end
@@ -103,26 +110,30 @@ describe 'ceilometer::agent::polling' do
       }
     end
 
-    context 'when tenant_name_discovery is set' do
+    context 'when common parameters are set' do
       before do
         params.merge!(
-          :tenant_name_discovery => true
-        )
-      end
-
-      it {
-        should contain_ceilometer_config('polling/tenant_name_discovery').with_value(true)
-      }
-    end
-
-    context 'when pollsters_definitions_dirs is set' do
-      before do
-        params.merge!(
-          :pollsters_definitions_dirs => ['/etc/ceilometer/pollsters.d', '/etc/ceilometer/mypollsters.d']
+          :identity_name_discovery     => true,
+          :ignore_disabled_projects    => false,
+          :enable_notifications        => true,
+          :enable_prometheus_exporter  => false,
+          :prometheus_listen_addresses => ['127.0.0.1:9101'],
+          :prometheus_tls_enable       => false,
+          :prometheus_tls_certfile     => 'certfile',
+          :prometheus_tls_keyfile      => 'keyfile',
+          :pollsters_definitions_dirs  => ['/etc/ceilometer/pollsters.d', '/etc/ceilometer/mypollsters.d']
         )
       end
 
       it {
+        should contain_ceilometer_config('polling/identity_name_discovery').with_value(true)
+        should contain_ceilometer_config('polling/ignore_disabled_projects').with_value(false)
+        should contain_ceilometer_config('polling/enable_notifications').with_value(true)
+        should contain_ceilometer_config('polling/enable_prometheus_exporter').with_value(false)
+        should contain_ceilometer_config('polling/prometheus_listen_addresses').with_value('127.0.0.1:9101')
+        should contain_ceilometer_config('polling/prometheus_tls_enable').with_value(false)
+        should contain_ceilometer_config('polling/prometheus_tls_certfile').with_value('certfile')
+        should contain_ceilometer_config('polling/prometheus_tls_keyfile').with_value('keyfile')
         should contain_ceilometer_config('polling/pollsters_definitions_dirs').with_value(
           '/etc/ceilometer/pollsters.d,/etc/ceilometer/mypollsters.d')
       }
@@ -207,15 +218,14 @@ describe 'ceilometer::agent::polling' do
      end
 
       it { should contain_file('polling').with(
-        :ensure                  => 'present',
-        :path                    => '/etc/ceilometer/polling.yaml',
-        :content                 => '---
+        :ensure  => 'file',
+        :path    => '/etc/ceilometer/polling.yaml',
+        :content => '---
 sources:
     - name: some_pollsters
       interval: 300
       meters:
         - cpu
-        - cpu_l3_cache
         - memory.usage
         - network.incoming.bytes
         - network.incoming.packets
@@ -229,23 +239,24 @@ sources:
         - volume.snapshot.size
         - volume.backup.size
 ',
-        :selinux_ignore_defaults => true,
-        :tag                     => 'ceilometer-yamls',
+        :tag     => 'ceilometer-yamls',
       )}
       it { should contain_ceilometer_config('polling/cfg_file').with_value('/etc/ceilometer/polling.yaml') }
     end
 
     context 'with polling and basic custom settings' do
       before do
-        params.merge!( :manage_polling   => true,
-                       :polling_interval => 30,
-                       :polling_meters   => ['meter1', 'meter2'] )
+        params.merge!({
+          :manage_polling   => true,
+          :polling_interval => 30,
+          :polling_meters   => ['meter1', 'meter2']
+        })
       end
 
       it { should contain_file('polling').with(
-        :ensure  => 'present',
+        :ensure  => 'file',
         :path    => '/etc/ceilometer/polling.yaml',
-        :content                 => '---
+        :content => '---
 sources:
     - name: some_pollsters
       interval: 30
@@ -253,8 +264,7 @@ sources:
         - meter1
         - meter2
 ',
-        :selinux_ignore_defaults => true,
-        :tag                     => 'ceilometer-yamls',
+        :tag     => 'ceilometer-yamls',
       )}
       it { should contain_ceilometer_config('polling/cfg_file').with_value('/etc/ceilometer/polling.yaml') }
     end
@@ -275,9 +285,9 @@ sources:
       end
 
       it { should contain_file('polling').with(
-        :ensure  => 'present',
+        :ensure  => 'file',
         :path    => '/etc/ceilometer/polling.yaml',
-        :content                 => '---
+        :content => '---
 sources:
 - name: my_pollsters
   interval: 60
