@@ -13,6 +13,7 @@ describe 'ceilometer::cache' do
         is_expected.to contain_oslo__cache('ceilometer_config').with(
           :config_prefix                        => '<SERVICE DEFAULT>',
           :expiration_time                      => '<SERVICE DEFAULT>',
+          :backend_expiration_time              => '<SERVICE DEFAULT>',
           :backend                              => '<SERVICE DEFAULT>',
           :backend_argument                     => '<SERVICE DEFAULT>',
           :proxies                              => '<SERVICE DEFAULT>',
@@ -59,6 +60,7 @@ describe 'ceilometer::cache' do
         {
           :config_prefix                        => 'prefix',
           :expiration_time                      => 3600,
+          :backend_expiration_time              => 7200,
           :backend                              => 'oslo_cache.memcache_pool',
           :proxies                              => ['proxy01:8888', 'proxy02:8888'],
           :enabled                              => true,
@@ -98,6 +100,7 @@ describe 'ceilometer::cache' do
         is_expected.to contain_oslo__cache('ceilometer_config').with(
           :config_prefix                        => 'prefix',
           :expiration_time                      => 3600,
+          :backend_expiration_time              => 7200,
           :backend                              => 'oslo_cache.memcache_pool',
           :backend_argument                     => '<SERVICE DEFAULT>',
           :proxies                              => ['proxy01:8888', 'proxy02:8888'],
