@@ -73,7 +73,7 @@ describe 'ceilometer' do
 
     context 'without the required telemetry_secret' do
       before { params.delete(:telemetry_secret) }
-      it { expect { is_expected.to raise_error(Puppet::Error) } }
+      it { is_expected.to raise_error(Puppet::Error) }
     end
 
     it 'configures default transport_url' do
@@ -147,17 +147,20 @@ describe 'ceilometer' do
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
         :kombu_failover_strategy         => '<SERVICE DEFAULT>',
         :kombu_compression               => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :use_queue_manager               => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
@@ -186,13 +189,11 @@ describe 'ceilometer' do
       before { params.merge!(
         :rabbit_heartbeat_timeout_threshold => '60',
         :rabbit_heartbeat_rate              => '10',
-        :rabbit_heartbeat_in_pthread        => true,
       ) }
 
       it { is_expected.to contain_oslo__messaging__rabbit('ceilometer_config').with(
         :heartbeat_timeout_threshold => '60',
         :heartbeat_rate              => '10',
-        :heartbeat_in_pthread        => true,
       ) }
     end
   end
